@@ -1,22 +1,21 @@
-/*
- * spelling-job.c
+/* spelling-job.c
  *
  * Copyright 2024 Christian Hergert <chergert@redhat.com>
  *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of the
+ * License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -25,6 +24,7 @@
 
 #include "spelling-dictionary-internal.h"
 #include "spelling-job-private.h"
+#include "spelling-trace.h"
 
 #define GDK_ARRAY_NAME spelling_boundaries
 #define GDK_ARRAY_TYPE_NAME SpellingBoundaries
@@ -318,9 +318,12 @@ spelling_job_check (GTask        *task,
   result = g_array_new (FALSE, FALSE, sizeof (SpellingMistakes));
   g_array_set_clear_func (result, clear_mistakes);
 
+  SPELLING_PROFILER_LOG ("Checking %u fragments", self->fragments->len);
+
   for (guint f = 0; f < self->fragments->len; f++)
     {
       const SpellingFragment *fragment = &g_array_index (self->fragments, SpellingFragment, f);
+      G_GNUC_UNUSED g_autofree char *message = NULL;
       g_autoptr(GtkBitset) bitset = NULL;
       g_autofree PangoLogAttr *attrs = NULL;
       SpellingMistakes mistakes;
@@ -332,6 +335,8 @@ spelling_job_check (GTask        *task,
       gsize i;
       guint pos;
 
+      SPELLING_PROFILER_BEGIN_MARK
+
       spelling_boundaries_clear (&boundaries);
 
       mistakes.fragment = fragment;
@@ -393,6 +398,14 @@ spelling_job_check (GTask        *task,
 
           g_array_append_val (result, mistakes);
         }
+
+      if G_UNLIKELY (SPELLING_PROFILER_ACTIVE)
+        message = g_strdup_printf ("%u chars, %u bytes, %u mistakes",
+                                   (guint)attrslen,
+                                   (guint)textlen,
+                                   mistakes.boundaries ? mistakes.boundaries->len : 0);
+
+      SPELLING_PROFILER_END_MARK ("Check", message);
     }
 
   spelling_boundaries_clear (&boundaries);
